Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(6161)

Unified Diff: chrome/renderer/net/net_error_page_controller.h

Issue 422933002: Shift the error page "More" button over to text. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Sync'c to r287451 to get past removal of chrome/browser/resources/ssl/blocking.html and thus the pr… Created 6 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/common/localized_error.cc ('k') | chrome/renderer/net/net_error_page_controller.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/renderer/net/net_error_page_controller.h
diff --git a/chrome/renderer/net/net_error_page_controller.h b/chrome/renderer/net/net_error_page_controller.h
index 9c5314ab564a06450e64144a391be8b99c1d5fd7..9be5bf479455b821b6f47cf6360bd52a727b2bcd 100644
--- a/chrome/renderer/net/net_error_page_controller.h
+++ b/chrome/renderer/net/net_error_page_controller.h
@@ -36,8 +36,8 @@ class NetErrorPageController
// Execute a "Reload" button click.
bool ReloadButtonClick();
- // Execute a "More" button click.
- bool MoreButtonClick();
+ // Execute a "Details" button click.
+ bool DetailsButtonClick();
// Track a click when the page has suggestions from the navigation correction
// service.
« no previous file with comments | « chrome/common/localized_error.cc ('k') | chrome/renderer/net/net_error_page_controller.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698